"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const util_1 = require("util");
// @ts-ignore
const package_json_1 = require("../package.json");
const args_1 = require("./args");
const readFile = (0, util_1.promisify)(fs_1.default.readFile);
const validCommands = ["restart", "start", "status", "stop"];
function processArgs(args) {
    if (args.find((arg) => arg === "--version")) {
        return ["PRINT_VERSION", ""];
    }
    if (args.find((arg) => arg === "--help")) {
        return ["PRINT_HELP", ""];
    }
    return ["INVOKE_CORE_D", args[0]];
}
async function main(args) {
    const [action, cmdOrFilename] = processArgs(args);
    if (action === "PRINT_VERSION") {
        console.log(`prettierd ${package_json_1.version}`);
        return;
    }
    else if (action === "PRINT_HELP") {
        (0, args_1.displayHelp)();
        return;
    }
    const title = "prettierd";
    process.env.CORE_D_TITLE = title;
    process.env.CORE_D_SERVICE = require.resolve("./service");
    process.env.CORE_D_DOTFILE = `.${title}`;
    const core_d = require("core_d");
    if (validCommands.includes(cmdOrFilename)) {
        core_d[cmdOrFilename]();
        return;
    }
    core_d.invoke(args, await readFile(process.stdin.fd, { encoding: "utf-8" }));
}
main(process.argv.slice(2)).catch((err) => {
    console.error(err);
    process.exit(1);
});
